@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -18,7 +18,6 @@
 #include "preferences.h"
 #include "resourcescalendar.h"
 #include "templatelistview.h"
-#include "templatemenuaction.h"
 #include "resources/calendarfunctions.h"
 #include "resources/datamodel.h"
 #include "resources/resources.h"
@@ -130,7 +129,7 @@ const QLatin1String ALARM_OPTS_FILE("alarmopts");
 const char*         DONT_SHOW_ERRORS_GROUP = "DontShowErrors";
 
 KAlarm::UpdateResult updateEvent(KAEvent&, KAlarm::UpdateError, QWidget* msgParent, bool saveIfReadOnly);
-void editNewTemplate(EditAlarmDlg::Type, const KAEvent* preset, QWidget* parent);
+void editNewTemplate(EditAlarmDlg::Type, const KAEvent& preset, QWidget* parent);
 void displayUpdateError(QWidget* parent, KAlarm::UpdateError, const UpdateStatusData&, bool showKOrgError = true);
 KAlarm::UpdateResult sendToKOrganizer(const KAEvent&);
 KAlarm::UpdateResult deleteFromKOrganizer(const QString& eventID);
@@ -824,8 +823,10 @@ QVector<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
         (*model)->setEventTypeFilter(CalEvent::ACTIVE);
         (*model)->sort(AlarmListModel::TimeColumn);
     }
+    int count = (*model)->rowCount();
     QVector<KAEvent> result;
-    for (int i = 0, count = (*model)->rowCount();  i < count;  ++i)
+    result.reserve(count);
+    for (int i = 0;  i < count;  ++i)
     {
         const KAEvent event = (*model)->event(i);
         if (event.enabled()  &&  !event.expired())
@@ -1051,10 +1052,14 @@ void displayKOrgUpdateError(QWidget* parent, UpdateError code, const UpdateResul
 * Execute a New Alarm dialog for the specified alarm type.
 */
 void editNewAlarm(EditAlarmDlg::Type type, QWidget* parent)
+{
+    editNewAlarm(type, QDate(), parent);
+}
+void editNewAlarm(EditAlarmDlg::Type type, const QDate& startDate, QWidget* parent)
 {
     EditAlarmDlg* editDlg = EditAlarmDlg::create(false, type, parent);
     if (editDlg)
-        execNewAlarmDlg(editDlg);
+        execNewAlarmDlg(editDlg, startDate);
 }
 
 /******************************************************************************
@@ -1095,18 +1100,29 @@ void editNewAlarm(KAEvent::SubAction action, QWidget* parent, const AlarmText* t
 * Execute a New Alarm dialog, optionally either presetting it to the supplied
 * event, or setting the action and text.
 */
-void editNewAlarm(const KAEvent* preset, QWidget* parent)
+void editNewAlarm(const KAEvent& preset, QWidget* parent)
+{
+    editNewAlarm(preset, QDate(), parent);
+}
+void editNewAlarm(const KAEvent& preset, const QDate& startDate, QWidget* parent)
 {
     EditAlarmDlg* editDlg = EditAlarmDlg::create(false, preset, true, parent);
     if (editDlg)
-        execNewAlarmDlg(editDlg);
+        execNewAlarmDlg(editDlg, startDate);
 }
 
 /******************************************************************************
 * Common code for editNewAlarm() variants.
 */
-void execNewAlarmDlg(EditAlarmDlg* editDlg)
+void execNewAlarmDlg(EditAlarmDlg* editDlg, const QDate& startDate)
 {
+    if (startDate.isValid())
+    {
+        KADateTime defaultTime = editDlg->time();
+        defaultTime.setDate(startDate);
+        editDlg->setTime(defaultTime);
+    }
+
     // Create a PrivateNewAlarmDlg parented by editDlg.
     // It will be deleted when editDlg is closed.
     new PrivateNewAlarmDlg(editDlg);
@@ -1181,7 +1197,7 @@ bool editNewAlarm(const QString& templateName, QWidget* parent)
         KAEvent templateEvent = ResourcesCalendar::templateEvent(templateName);
         if (templateEvent.isValid())
         {
-            editNewAlarm(&templateEvent, parent);
+            editNewAlarm(templateEvent, parent);
             return true;
         }
         qCWarning(KALARM_LOG) << "KAlarm::editNewAlarm:" << templateName << ": template not found";
@@ -1194,13 +1210,13 @@ bool editNewAlarm(const QString& templateName, QWidget* parent)
 */
 void editNewTemplate(EditAlarmDlg::Type type, QWidget* parent)
 {
-    ::editNewTemplate(type, nullptr, parent);
+    ::editNewTemplate(type, KAEvent(), parent);
 }
 
 /******************************************************************************
 * Create a new template, based on an existing event or template.
 */
-void editNewTemplate(const KAEvent* preset, QWidget* parent)
+void editNewTemplate(const KAEvent& preset, QWidget* parent)
 {
     ::editNewTemplate(EditAlarmDlg::Type(0), preset, parent);
 }
@@ -1256,7 +1272,7 @@ void cancelRtcWake(QWidget* msgParent, const QString& eventId)
     if (!wakeup.isEmpty()  &&  (eventId.isEmpty() || wakeup[0] == eventId))
     {
         Private::instance()->mMsgParent = msgParent ? msgParent : MainWindow::mainMainWindow();
-        QTimer::singleShot(0, Private::instance(), &Private::cancelRtcWake);
+        QTimer::singleShot(0, Private::instance(), &Private::cancelRtcWake);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     }
 }
 
@@ -1345,7 +1361,7 @@ KAlarm::UpdateResult updateEvent(KAEvent& event, KAlarm::UpdateError err, QWidge
 * 'preset' is non-null to base it on an existing event or template; otherwise,
 * the alarm type is set to 'type'.
 */
-void editNewTemplate(EditAlarmDlg::Type type, const KAEvent* preset, QWidget* parent)
+void editNewTemplate(EditAlarmDlg::Type type, const KAEvent& preset, QWidget* parent)
 {
     if (Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty())
     {
@@ -1356,7 +1372,7 @@ void editNewTemplate(EditAlarmDlg::Type type, const KAEvent* preset, QWidget* pa
     // the dialogue is still open. It prevents double deletion (both on
     // deletion of parent, and on return from this function).
     AutoQPointer<EditAlarmDlg> editDlg;
-    if (preset)
+    if (preset.isValid())
         editDlg = EditAlarmDlg::create(true, preset, true, parent);
     else
         editDlg = EditAlarmDlg::create(true, type, parent);
@@ -1380,14 +1396,14 @@ namespace KAlarm
 * Open the Edit Alarm dialog to edit the specified alarm.
 * If the alarm is read-only or archived, the dialog is opened read-only.
 */
-void editAlarm(KAEvent* event, QWidget* parent)
+void editAlarm(KAEvent& event, QWidget* parent)
 {
-    if (event->expired()  ||  eventReadOnly(event->id()))
+    if (event.expired()  ||  eventReadOnly(event.id()))
     {
         viewAlarm(event, parent);
         return;
     }
-    const EventId id(*event);
+    const EventId id(event);
     // Use AutoQPointer to guard against crash on application exit while
     // the dialogue is still open. It prevents double deletion (both on
     // deletion of parent, and on return from this function).
@@ -1406,7 +1422,7 @@ void editAlarm(KAEvent* event, QWidget* parent)
         bool changeDeferral = !editDlg->getEvent(newEvent, resource);
 
         // Update the event in the displays and in the calendar file
-        const Undo::Event undo(*event, resource);
+        const Undo::Event undo(event, resource);
         if (changeDeferral)
         {
             // The only change has been to an existing deferral
@@ -1415,7 +1431,7 @@ void editAlarm(KAEvent* event, QWidget* parent)
         }
         else
         {
-            const UpdateResult status = modifyEvent(*event, newEvent, editDlg);
+            const UpdateResult status = modifyEvent(event, newEvent, editDlg);
             if (status.status != UPDATE_OK  &&  status.status <= UPDATE_KORG_ERR)
                 displayKOrgUpdateError(editDlg, ERR_MODIFY, status);
         }
@@ -1456,7 +1472,7 @@ bool editAlarmById(const EventId& id, QWidget* parent)
             qCCritical(KALARM_LOG) << "KAlarm::editAlarmById:" << eventID << ": event not active or template";
             return false;
     }
-    editAlarm(&event, parent);
+    editAlarm(event, parent);
     return true;
 }
 
@@ -1464,9 +1480,9 @@ bool editAlarmById(const EventId& id, QWidget* parent)
 * Open the Edit Alarm dialog to edit the specified template.
 * If the template is read-only, the dialog is opened read-only.
 */
-void editTemplate(KAEvent* event, QWidget* parent)
+void editTemplate(KAEvent& event, QWidget* parent)
 {
-    if (eventReadOnly(event->id()))
+    if (eventReadOnly(event.id()))
     {
         // The template is read-only, so make the dialogue read-only.
         // Use AutoQPointer to guard against crash on application exit while
@@ -1486,12 +1502,12 @@ void editTemplate(KAEvent* event, QWidget* parent)
         KAEvent newEvent;
         Resource resource;
         editDlg->getEvent(newEvent, resource);
-        const QString id = event->id();
+        const QString id = event.id();
         newEvent.setEventId(id);
-        newEvent.setResourceId(event->resourceId());
+        newEvent.setResourceId(event.resourceId());
 
         // Update the event in the displays and in the calendar file
-        const Undo::Event undo(*event, resource);
+        const Undo::Event undo(event, resource);
         updateTemplate(newEvent, editDlg);
         Undo::saveEdit(undo, newEvent);
     }
@@ -1500,7 +1516,7 @@ void editTemplate(KAEvent* event, QWidget* parent)
 /******************************************************************************
 * Open the Edit Alarm dialog to view the specified alarm (read-only).
 */
-void viewAlarm(const KAEvent* event, QWidget* parent)
+void viewAlarm(const KAEvent& event, QWidget* parent)
 {
     // Use AutoQPointer to guard against crash on application exit while
     // the dialogue is still open. It prevents double deletion (both on
@@ -1738,7 +1754,8 @@ bool convertTimeString(const QByteArray& timeString, KADateTime& dateTime, const
         return false;
     QString zone = (i >= 0) ? QString::fromLatin1(timeString.mid(i)) : QString();
     char timeStr[MAX_DT_LEN+1];
-    strcpy(timeStr, timeString.left(i >= 0 ? i : MAX_DT_LEN).constData());
+    strncpy(timeStr, timeString.left(i >= 0 ? i : MAX_DT_LEN).constData(), MAX_DT_LEN);
+    timeStr[MAX_DT_LEN] = '\0';
     int dt[5] = { -1, -1, -1, -1, -1 };
     char* s;
     char* end;
