@@ -1,21 +1,9 @@
 /*
  *  packedlayout.cpp  -  layout to pack items into rows
  *  Program:  kalarm
- *  Copyright © 2007-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "packedlayout.h"
@@ -104,7 +92,7 @@ QSize PackedLayout::minimumSize() const
         size = size.expandedTo(mItems[i]->minimumSize());
     int left, top, right, bottom;
     getContentsMargins(&left, &top, &right, &bottom);
-    return QSize(size.width() + left + right, size.height() + top + bottom);
+    return {size.width() + left + right, size.height() + top + bottom};
 }
 
 // Arranges widgets and returns height required.
@@ -113,8 +101,8 @@ int PackedLayout::arrange(const QRect& rect, bool set) const
     int x = rect.x();
     int y = rect.y();
     int yrow = 0;
-    QList<QRect> posn;
-    QList<QLayoutItem*> items;
+    QVector<QRect> posn;
+    QVector<QLayoutItem*> items;
     for (QLayoutItem* item : qAsConst(mItems))
     {
         if (item->isEmpty())
