@@ -1,21 +1,9 @@
 /*
  *  stackedwidgets.cpp  -  group of stacked widgets
  *  Program:  kalarm
- *  Copyright © 2008 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2008, 2020 David Jarvie <djarvie@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "stackedwidgets.h"
@@ -38,11 +26,8 @@ StackedScrollWidget::StackedScrollWidget(StackedScrollGroup* group, QWidget* par
 }
 
 StackedScrollGroup::StackedScrollGroup(QDialog* dlg, QObject* tabParent)
-    : StackedGroupT<QScrollArea>(tabParent),
-      mDialog(dlg),
-      mMinHeight(-1),
-      mHeightReduction(0),
-      mSized(false)
+    : StackedGroupT<QScrollArea>(tabParent)
+    , mDialog(dlg)
 {
 }
 
@@ -56,9 +41,9 @@ StackedScrollGroup::StackedScrollGroup(QDialog* dlg, QObject* tabParent)
 */
 QSize StackedScrollGroup::minimumSizeHint() const
 {
-    QSize s = maxMinimumSizeHint();
+    const QSize s = maxMinimumSizeHint();
     if (!s.isEmpty()  &&  mMinHeight > 0  &&  mMinHeight < s.height())
-        return QSize(s.width() + mWidgets[0]->style()->pixelMetric(QStyle::PM_ScrollBarExtent), mMinHeight);
+        return {s.width() + mWidgets[0]->style()->pixelMetric(QStyle::PM_ScrollBarExtent), mMinHeight};
     return s;
 }
 
@@ -68,12 +53,12 @@ QSize StackedScrollGroup::minimumSizeHint() const
 QSize StackedScrollGroup::maxMinimumSizeHint() const
 {
     QSize sz;
-    for (int i = 0, count = mWidgets.count();  i < count;  ++i)
+    for (const auto& sw : mWidgets)
     {
-        QWidget* w = static_cast<StackedScrollWidget*>(mWidgets[i])->widget();
+        QWidget* w = static_cast<StackedScrollWidget*>(sw)->widget();
         if (!w)
-            return QSize();
-        QSize s = w->minimumSizeHint();
+            return {};
+        const QSize s = w->minimumSizeHint();
         if (!s.isValid())
             return QSize();
         sz = sz.expandedTo(s);
@@ -91,24 +76,24 @@ QSize StackedScrollGroup::adjustSize(bool force)
     if (force)
         mSized = false;
     if (mSized)
-        return QSize();
+        return {};
 
     // Cancel any previous minimum height and set the height of the
     // scroll widget contents widgets.
     mMinHeight = -1;
     mHeightReduction = 0;
-    QSize s = maxMinimumSizeHint();
+    const QSize s = maxMinimumSizeHint();
     if (s.isEmpty())
         return QSize();
-    int maxTabHeight = s.height();
-    for (int i = 0, count = mWidgets.count();  i < count;  ++i)
+    const int maxTabHeight = s.height();
+    for (auto& sw : mWidgets)
     {
-        mWidgets[i]->setMinimumHeight(maxTabHeight);
-        QWidget* w = static_cast<StackedScrollWidget*>(mWidgets[i])->widget();
+        sw->setMinimumHeight(maxTabHeight);
+        QWidget* w = static_cast<StackedScrollWidget*>(sw)->widget();
         if (w)
             w->resize(s);
     }
-    for (QWidget* w = mWidgets[0]->parentWidget();  w && w != mDialog;  w = w->parentWidget())
+    for (QWidget* w = mWidgets.at(0)->parentWidget();  w && w != mDialog;  w = w->parentWidget())
     {
         w->setMinimumHeight(0);
         w->adjustSize();
@@ -122,12 +107,12 @@ QSize StackedScrollGroup::adjustSize(bool force)
         // available, so use a guess of 25 pixels.
         decoration = 25;
     }
-    int desk = Desktop::workArea().height();
+    const int desk = Desktop::workArea().height();
     // There is no stored size, or the deferral group is visible.
     // Allow the tab contents to be scrolled vertically if that is necessary
     // to avoid the dialog exceeding the screen height.
     QSize dlgsize = mDialog->QDialog::minimumSizeHint();
-    int y = dlgsize.height() + decoration - desk;
+    const int y = dlgsize.height() + decoration - desk;
     if (y > 0)
     {
         mHeightReduction = y;
@@ -135,18 +120,18 @@ QSize StackedScrollGroup::adjustSize(bool force)
         qCDebug(KALARM_LOG) << "StackedScrollGroup::adjustSize: Scrolling: max tab height=" << maxTabHeight << ", reduction=" << mHeightReduction << "-> min tab height=" << mMinHeight;
         if (mMinHeight > 0)
         {
-            for (int i = 0, count = mWidgets.count();  i < count;  ++i)
+            for (auto& sw : mWidgets)
             {
-                mWidgets[i]->setMinimumHeight(mMinHeight);
-                mWidgets[i]->resize(QSize(mWidgets[i]->width(), mMinHeight));
+                sw->setMinimumHeight(mMinHeight);
+                sw->resize(QSize(sw->width(), mMinHeight));
             }
         }
         mSized = true;
-        QSize s = mWidgets[0]->parentWidget()->sizeHint();
+        QSize s = mWidgets.at(0)->parentWidget()->sizeHint();
         if (s.height() < mMinHeight)
             s.setHeight(mMinHeight);
-        mWidgets[0]->parentWidget()->resize(s);
-        for (QWidget* w = mWidgets[0]->parentWidget();  w && w != mDialog;  w = w->parentWidget())
+        mWidgets.at(0)->parentWidget()->resize(s);
+        for (QWidget* w = mWidgets.at(0)->parentWidget();  w && w != mDialog;  w = w->parentWidget())
             w->setMinimumHeight(qMin(w->minimumSizeHint().height(), w->sizeHint().height()));
         dlgsize.setHeight(dlgsize.height() - mHeightReduction);
         s = mDialog->QDialog::minimumSizeHint();
