@@ -91,8 +91,9 @@ QModelIndexList ResourceFilterModel::match(const QModelIndex& start, int role, c
     if (role < Qt::UserRole)
         return QSortFilterProxyModel::match(start, role, value, hits, flags);
 
-    QModelIndexList matches;            //clazy:exclude=inefficient-qlist
     const QModelIndexList indexes = sourceModel()->match(mapToSource(start), role, value, hits, flags);     //clazy:exclude=inefficient-qlist
+    QModelIndexList matches;            //clazy:exclude=inefficient-qlist
+    matches.reserve(indexes.count());
     for (const QModelIndex& ix : indexes)
     {
         QModelIndex proxyIndex = mapFromSource(ix);
@@ -388,7 +389,7 @@ void ResourceCheckListModel::selectionChanged(const QItemSelection& selected, co
     }
     const QModelIndexList desel = deselected.indexes();       //clazy:exclude=inefficient-qlist
     for (const QModelIndex& ix : desel)
-        mModel->resource(ix).setEnabled(mAlarmType, false);
+        mModel->resource(ix).setEnabled(mAlarmType, false);   //clazy:exclude=writing-to-temporary
 }
 
 /******************************************************************************
