@@ -77,7 +77,7 @@ class UndoMultiBase : public UndoItem
                 : UndoItem(t, name), mUndos(new Undo::List) {}
         UndoMultiBase(Undo::Type t, Undo::List* undos, const QString& name)
                 : UndoItem(t, name), mUndos(undos) {}
-        ~UndoMultiBase()  { delete mUndos; }
+        ~UndoMultiBase() override { delete mUndos; }
         const Undo::List* undos() const         { return mUndos; }
     protected:
         void               dumpDebugTitle(const char* typeName) const override;
@@ -125,7 +125,7 @@ class UndoEdit : public UndoItem
     public:
         UndoEdit(Undo::Type, const KAEvent& oldEvent, const QString& newEventID,
                  const Resource&, const QStringList& dontShowErrors, const QString& description);
-        ~UndoEdit();
+        ~UndoEdit() override;
         Operation          operation() const override     { return EDIT; }
         QString            defaultActionText() const override;
         QString            description() const override   { return mDescription; }
@@ -150,7 +150,7 @@ class UndoDelete : public UndoItem
     public:
         UndoDelete(Undo::Type, const Undo::Event&, const QString& name = QString());
         UndoDelete(Undo::Type, const KAEvent&, const Resource&, const QStringList& dontShowErrors, const QString& name = QString());
-        ~UndoDelete();
+        ~UndoDelete() override;
         Operation          operation() const override     { return DELETE; }
         QString            defaultActionText() const override;
         QString            description() const override   { return UndoItem::description(*mEvent); }
@@ -729,7 +729,7 @@ UndoMulti<T>::UndoMulti(Undo::Type type, const Undo::EventList& events, const QS
 template <class T>
 UndoItem* UndoMulti<T>::restore()
 {
-    auto* newUndos = new Undo::List;
+    auto newUndos = new Undo::List;
     for (int i = 0, end = mUndos->count();  i < end;  ++i)
     {
         UndoItem* undo = (*mUndos)[i]->restore();
@@ -1247,7 +1247,7 @@ QString UndoDeletes::defaultActionText() const
 {
     if (mUndos->isEmpty())
         return QString();
-    for (const UndoItem* item : *mUndos)
+    for (const UndoItem* item : qAsConst(*mUndos))
     {
         switch (item->calendar())
         {
